﻿#define USE_DATATABLE

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using System.Diagnostics;
using InvokeSolutions.Docx;
using System.Data;
using InvokeSolutions.Docx.Data;

namespace SampleNestedTables
{
    class Program
    {
        /// <summary>
        /// Get sample DataTable with nested one 
        /// </summary>
        /// <returns></returns>
        static DataTable FindCustomersSomeWhere()
        {
            // create parent table
            DataTable table = new DataTable();

            // declare columns
            table.Columns.Add("NAME");
            table.Columns.Add("PAYMENTS", typeof(DataTable));
            table.Columns.Add("TOTAL_PAYMENTS");

            // create first child table
            DataTable tableRow1 = new DataTable();
            // define its columns
            tableRow1.Columns.Add("DATE");
            tableRow1.Columns.Add("AMOUNT");
            
            // add nested table data
            tableRow1.Rows.Add("01/02/03", "$ 1.00");
            tableRow1.Rows.Add("01/03/05", "$ 2.00");
            tableRow1.Rows.Add("01/04/06", "$ 5.00");

            // add first parent table row
            table.Rows.Add("Failboat inc.", tableRow1, "$ 8.00");

            // create second row
            DataTable tableRow2 = new DataTable();
            tableRow2.Columns.Add("DATE");
            tableRow2.Columns.Add("AMOUNT");

            tableRow2.Rows.Add("01/02/08", "$ 2.00");
            tableRow2.Rows.Add("01/03/08", "$ 2.00");
            tableRow2.Rows.Add("01/04/08", "$ 5.00");

            table.Rows.Add("Big pony ltd.", tableRow2, "$ 9.00");

            // create third row
            DataTable tableRow3 = new DataTable();
            tableRow3.Columns.Add("DATE");
            tableRow3.Columns.Add("AMOUNT");

            tableRow3.Rows.Add("--/--/--", "---");

            table.Rows.Add("%Little% horse ltd.", tableRow3, "$ 0.00");

            return table;
        }

        static void Main(string[] args)
        {
            // copy template
            File.Copy("templates\\nestedtables.docx", "compiled\\nestedtables_compiled.docx", true);
            File.Copy("templates\\0.docx", "compiled\\0.docx", true);
            File.Copy("templates\\1.docx", "compiled\\1.docx", true);
            File.Copy("templates\\2.docx", "compiled\\2.docx", true);
            File.Copy("templates\\3.docx", "compiled\\3.docx", true);
            File.Copy("templates\\4.docx", "compiled\\4.docx", true);

            // crate data source
            DocumentDataSource dataSource = new DocumentDataSource();

            // prepare table data (TableDataItem)
#if USE_DATATABLE

            // it can be converted from DataTable

            var data = FindCustomersSomeWhere();

#else
            // or using anonymous types
            var order = new { Amount = 100, Date = DateTime.Today, Customer = "FBI", Invoice_Id = 55, Quantity = 1, Service = "Delivering Bin Laden to Guantanamo" };

            var data = new[] { new { NAME = "JOHN", TOTAL_PAYMENTS = 1, PAYMENTS = new[] { order } } };
#endif
            // assign other parameters

            dataSource["DATE"] = new HyperLinkDataItem(DateTime.Today.ToLongDateString(), "http://1.2.3");
            dataSource["CUSTOMERS"] = DataItem.ConvertFrom(data);
            dataSource["TOTAL_CUSTOMERS"] = "%NEW_TOTAL_CUSTOMERS%";
            dataSource["TOTAL_PAYMENTS"] = "$ 17.00";

            //dataSource.EmptyValue = " ";

            // process
            InvokeSolutions.Docx.DocumentRenderer.ProcessDocument("compiled\\nestedtables_compiled.docx", dataSource);
            /*DocumentRenderer.ProcessDocument("compiled\\0.docx", dataSource);
            DocumentRenderer.ProcessDocument("compiled\\1.docx", dataSource);
            DocumentRenderer.ProcessDocument("compiled\\2.docx", dataSource);
            DocumentRenderer.ProcessDocument("compiled\\3.docx", dataSource);
            DocumentRenderer.ProcessDocument("compiled\\4.docx", dataSource);*/

            // start merged document
            Process.Start("compiled\\nestedtables_compiled.docx");
        }
    }
}
